.. _dev-kit-API-const:

microspeclib.datatypes.types module (dev-kit API constants)
===========================================================

.. automodule:: microspeclib.datatypes.types
   :members:
   :undoc-members:
   :private-members:
   :special-members:
